PropertyReference

Enum PropertyReference 

pub enum PropertyReference {
    Local {
        sub_component_path: Vec<usize>,
        property_index: PropertyIndex,
    },
    InNativeItem {
        sub_component_path: Vec<usize>,
        item_index: usize,
        prop_name: String,
    },
    InParent {
        level: NonZeroUsize,
        parent_reference: Box<PropertyReference>,
    },
    Global {
        global_index: usize,
        property_index: usize,
    },
}
a Reference to a property, in the context of a SubComponent

Variants



Local

A property relative to this SubComponent

Fields

sub_component_path: Vec<usize>
property_index: PropertyIndex


InNativeItem

A property in a Native item

Fields

sub_component_path: Vec<usize>
item_index: usize
prop_name: String


InParent

The properties is a property relative to a parent ItemTree (level level deep)

Fields

parent_reference: Box<PropertyReference>


Global

The property within a GlobalComponent

Fields

global_index: usize
property_index: usize